3.5 Actuator Specifiers
=======================

List of Actuators Specifiers that are applicable to the Actuator. This
is an optional field. These specifiers are not present in the Language
Specification.

Type: Specifiers (Map)

.. list-table::
   :widths: 3 4 4 3 40
   :header-rows: 1

   * - ID
     - Name
     - Type
     - #
     - Description
   * - 1
     - domain
     - ``str``
     - 0
     - Domain under the responsibility of the actuator.
   * - 2
     - asset_id
     - ``str``
     - 0
     - Identifier of the actuator.

